@@ -9,12 +9,14 @@ from .waveform_modes import WaveformModes
 # from .waveform_grid import WaveformGrid
 # from .waveform_signal import WaveformSignal
 
-from . import nrar, rotating_paired_xor_multishuffle_bzip2, memory, transformations #, corotating_paired_xor
+from . import nrar, rotating_paired_xor_multishuffle_bzip2, memory, transformations, alignment #, corotating_paired_xor
 
 formats = {
     None: nrar,
     "": nrar,
     "nrar": nrar,
     "rotating_paired_xor_multishuffle_bzip2": rotating_paired_xor_multishuffle_bzip2,
+    "rpxm": rotating_paired_xor_multishuffle_bzip2,
+    "rpxmb": rotating_paired_xor_multishuffle_bzip2,
     # "corotating_paired_xor": corotating_paired_xor,
 }
