@@ -264,7 +264,7 @@ def test_rpxmb():
             h5_file_name = file_name.with_suffix(".h5")
             sxs.rpxmb.save(w, file_name, L2norm_fractional_tolerance=L2norm_fractional_tolerance)
             print(f"File size = {h5_file_name.stat().st_size:_}B")
-            w2, _ = sxs.rpxmb.load(file_name)
+            w2 = sxs.rpxmb.load(file_name)
         diff_norm = np.linalg.norm(w.data-w2.data, axis=w.modes_axis)
         print(f"Max difference = {np.max(diff_norm)}")
         assert np.max(diff_norm) < L2norm_fractional_tolerance, (np.max(diff_norm), "\n", diff_norm)
